@@ -5,6 +5,12 @@ package Net::PcapWriter::UDP;
 use fields qw(flow writer);
 use Net::PcapWriter::IP;
 use Socket qw(AF_INET IPPROTO_UDP);
+BEGIN { 
+	# inet_pton is in Socket since 5.12
+	eval { Socket->import('inet_pton');1 }
+		or eval { require Socket6; Socket6->import('inet_pton');1 }
+		or die "you need either a modern perl or Socket6"
+}
 
 sub new {
 	my ($class,$writer,$src,$sport,$dst,$dport) = @_;
@@ -41,7 +47,8 @@ sub write {
 		$flow->[0],
 		$flow->[1],
 		IPPROTO_UDP,
-	), $timestamp );
+		$timestamp
+	));
 }
 
 1;
